==> ToolChain_STM32_1.0.51.tar.bz: ToolChain_STM32_1.0.51/CommonLibraries/scheduler/freertos_mutex.h <==
#ifndef freertos_mutex_H
#define freertos_mutex_H

/*{ freertos_mutex.h ***********************************************
 *
 * Written by Gregor Rebel 2012-2013
 *
 * Architecture independent support for inter task communication & synchronization by use of
 * multitasking scheduler FreeRTOS.
 *
}*/

//{ includes

#include "ttc_basic.h"
#include "ttc_mutex_types.h"

#include "ttc_task.h"

#include <string.h> //???
#include "stddef.h" //???
#include "FreeRTOS.h"
//? #include "mutex.h"
#include "semphr.h"
#include "portmacro.h"
#include "list.h"

#ifndef EXTENSION_300_scheduler_free_rtos
  #error Missing extension EXTENSION_300_scheduler_free_rtos (did you forget to activate it?)
#endif

//}includes
//{ Default settings (change via makefile) *******************************
//}Default settings
//{ Structures ***********************************************************

typedef struct QueueDefinition { // copied from mutex.c (use for debugging purpose only)
  signed char *pcHead;				/*< Points to the beginning of the mutex storage area. */
  signed char *pcTail;				/*< Points to the byte at the end of the mutex storage area.  Once more byte is allocated than necessary to store the mutex items, this is used as a marker. */

  signed char *pcWriteTo;				/*< Points to the free next place in the storage area. */
  signed char *pcReadFrom;			/*< Points to the last place that a mutexd item was read from. */

  xList xTasksWaitingToSend;		    /*< List of tasks that are blocked waiting to post onto this mutex.  Stored in priority order. */
  xList xTasksWaitingToReceive;		/*< List of tasks that are blocked waiting to read from this mutex.  Stored in priority order. */

  volatile Base_t uxMessagesWaiting;  /*< The number of items currently in the mutex. */
  Base_t uxLength;		            /*< The length of the mutex defined as the number of items it will hold, not the number of bytes. */
  Base_t uxItemSize;		            /*< The size of each items that the mutex will hold. */

  Base_signed_t xRxLock;			    /*< Stores the number of items received from the mutex (removed from the mutex) while the mutex was locked.  Set to mutexUNLOCKED when the mutex is not locked. */
  Base_signed_t xTxLock;			    /*< Stores the number of items transmitted to the mutex (added to the mutex) while the mutex was locked.  Set to mutexUNLOCKED when the mutex is not locked. */

#if ( configUSE_TRACE_FACILITY == 1 )
  unsigned char ucQueueNumber;
  unsigned char ucQueueType;
#endif

} xQUEUE_Structure;

//}Structures
//{ Low-Level driver macros for ttc_mutex.h ******************************

#define DRIVER_ttc_mutex_create()               freertos_mutex_create()
#define DRIVER_ttc_mutex_init(Mutex)            freertos_mutex_init(Mutex)
#define DRIVER_ttc_mutex_lock(Mutex, TimeOut)   freertos_mutex_lock(Mutex, TimeOut)
#define DRIVER_ttc_mutex_lock_isr(Mutex)        freertos_mutex_lock_isr(Mutex)
#define DRIVER_ttc_mutex_unlock(Mutex)          freertos_mutex_unlock(Mutex)
#define DRIVER_ttc_mutex_unlock_isr(Mutex)      freertos_mutex_unlock_isr(Mutex)

//typedef xQUEUE_Structure ttc_Mutex;
#define ttc_Mutex xQUEUE_Structure

//}
//{ includes2
#include "ttc_memory.h"
//} includes2
//{ Function prototypes **************************************************


/** creates a new non-recursive mutex lock
 * @return                 =! NULL: mutex has been created successfully (use handle to operate on mutex)
 */
ttc_Mutex* freertos_mutex_create();

/** Initializes given structure as mutex in unlocked state
 * @param Mutex  reference of ttc_Mutex-structure to init
 */
ttc_mutex_error_e freertos_mutex_init(xQUEUE_Structure* Mutex);

/** Tries to obtain lock on mutex within timeout
 * @param Mutex  handle of already created mutex
 * @param TimeOut  !=-1: amount of system ticks to wait for lock
 *                 ==-1: wait forever
 * @return         == tme_OK: Lock has been successfully obtained within TimeOut
 */
ttc_mutex_error_e freertos_mutex_lock(ttc_Mutex* Mutex, Base_t TimeOut);

/** Tries to obtain lock on mutex; this function will never block
 * @param Mutex                handle of already created mutex
 * @return         == tme_OK: Lock has been successfully obtained within TimeOut
 *                 == tme_HigherPriorityTaskWoken: - a task of higher priority has been interrupted => call ttc_task_yield() at end of your interrupt service routine!
 *                 >= tme_Error: Error condition
 */
ttc_mutex_error_e freertos_mutex_lock_isr(ttc_Mutex* Mutex);


/** Releases an already obtained lock from mutex
 * @param Mutex  handle of already created smart mutex
 * @return         == tme_OK: Lock has been released successfully
 */
ttc_mutex_error_e freertos_mutex_unlock(ttc_Mutex* Mutex);

/** Releases an already obtained lock from mutex (does never block)
 * @param Mutex  handle of already created mutex
 * @return         == tme_OK: Lock has been released successfully
 *                 == tme_HigherPriorityTaskWoken: call task ttc_task_yield_isr() before exiting your ISR!
 */
ttc_mutex_error_e freertos_mutex_unlock_isr(ttc_Mutex* Mutex);

/** called while waiting for mutex lock. Place your breakpoint inside to debug hanging locks
  */
void freertos_mutex_wait();

//}Function prototypes

#endif

==> ToolChain_STM32_1.0.52.tar.bz: ToolChain_STM32_1.0.52/CommonLibraries/scheduler/freertos_mutex.h <==
#ifndef freertos_mutex_H
#define freertos_mutex_H

/*{ freertos_mutex.h ***********************************************
 *
 * Written by Gregor Rebel 2012-2013
 *
 * Architecture independent support for inter task communication & synchronization by use of
 * multitasking scheduler FreeRTOS.
 *
}*/

//{ includes

#include "ttc_basic.h"
#include "freertos_mutex_types.h"
#include "freertos_queue_types.h"
#include "FreeRTOS.h"
#include "semphr.h"
#include "portmacro.h"
#include "list.h"

#ifndef EXTENSION_300_scheduler_free_rtos
  #error Missing extension EXTENSION_300_scheduler_free_rtos (did you forget to activate it?)
#endif

//}includes
//{ Default settings (change via makefile) *******************************
//}Default settings
//{ Structures ***********************************************************

//}Structures
//{ Low-Level driver macros for ttc_mutex.h ******************************

#define DRIVER_ttc_mutex_create()               freertos_mutex_create()
#define DRIVER_ttc_mutex_init(Mutex)            freertos_mutex_init(Mutex)
#define DRIVER_ttc_mutex_lock(Mutex, TimeOut)   freertos_mutex_lock(Mutex, TimeOut)
#define DRIVER_ttc_mutex_lock_isr(Mutex)        freertos_mutex_lock_isr(Mutex)
#define DRIVER_ttc_mutex_unlock(Mutex)          freertos_mutex_unlock(Mutex)
#define DRIVER_ttc_mutex_unlock_isr(Mutex)      freertos_mutex_unlock_isr(Mutex)
#define DRIVER_ttc_mutex_is_locked(Mutex)       freertos_mutex_is_locked(Mutex)

//}
//{ includes2

#include "ttc_mutex_types.h"
#include "ttc_memory.h"
#include "ttc_task.h"

//} includes2
//{ Function prototypes **************************************************


/** creates a new non-recursive mutex lock
 * @return                 =! NULL: mutex has been created successfully (use handle to operate on mutex)
 */
ttc_mutex_t* freertos_mutex_create();

/** Initializes given structure as mutex in unlocked state
 * @param Mutex  reference of ttc_mutex_t-structure to init
 */
ttc_mutex_error_e freertos_mutex_init(ttc_mutex_t* Mutex);

/** Tries to obtain lock on mutex within timeout
 * @param Mutex  handle of already created mutex
 * @param TimeOut  !=-1: amount of system ticks to wait for lock
 *                 ==-1: wait forever
 * @return         == tme_OK: Lock has been successfully obtained within TimeOut
 */
ttc_mutex_error_e freertos_mutex_lock(ttc_mutex_t* Mutex, Base_t TimeOut);

/** Checks if given Mutex is currently locked
 * @param Mutex    handle of already created mutex
 * @return         == TRUE: given Mutex is currently in locked state; FALSE otherwise
 */
// BOOL freertos_mutex_is_locked(ttc_mutex_t* Mutex);
#define freertos_mutex_is_locked(Mutex) (Mutex && (Mutex->uxMessagesWaiting > 0))

/** Tries to obtain lock on mutex; this function will never block
 * @param Mutex                handle of already created mutex
 * @return         == tme_OK: Lock has been successfully obtained within TimeOut
 *                 == tme_WasLockedByTask: - a task of higher priority has been interrupted => call ttc_task_yield() at end of your interrupt service routine!
 *                 >= tme_Error: Error condition
 */
ttc_mutex_error_e freertos_mutex_lock_isr(ttc_mutex_t* Mutex);


/** Releases an already obtained lock from mutex
 * @param Mutex  handle of already created smart mutex
 * @return         == tme_OK: Lock has been released successfully
 */
ttc_mutex_error_e freertos_mutex_unlock(ttc_mutex_t* Mutex);

/** Releases an already obtained lock from mutex (does never block)
 * @param Mutex  handle of already created mutex
 * @return         == tme_OK: Lock has been released successfully
 *                 == tme_WasLockedByTask: call task ttc_task_yield_isr() before exiting your ISR!
 */
ttc_mutex_error_e freertos_mutex_unlock_isr(ttc_mutex_t* Mutex);


//}Function prototypes

#endif
